#' ShearModelParameters
#'
#' This dataset contains hear Model Parameters from Ishihara (1996)
#'
#' @format A data frame with 20 rows and 10 variables:
#' \describe{
#'  \item{ModelID}{Character: Model ID}
#'  \item{GroupID}{Character: Group ID}
#'  \item{NameID}{Character: NameID}
#'  \item{AuthorID}{Character: AuthorID}
#'  \item{emin}{Double: Min Void Ratio}
#'  \item{emax}{Double: Max Void Ratio}
#'  \item{A}{Double: A}
#'  \item{Ce}{Double: Ce}
#'  \item{n}{Double: Ce}
#'  \item{UN}{Character: Go Units}
#' }
#' @usage data(ShearModelParameters)
#' @docType data
#' @keywords datasets
#' @name ShearModelParameters
"ShearModelParameters"

