% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/interpolateSaTable.R
\name{interpolateSaTable}
\alias{interpolateSaTable}
\title{Interpolate Sa(p) at arbitrary period using log-log interpolation}
\usage{
interpolateSaTable(uhs, Tn)
}
\arguments{
\item{uhs}{data.table with columns Tn, p, Sa.}

\item{Tn}{numeric scalar — target period for interpolation.}
}
\value{
data.table with interpolated Tn, p, Sa
}
\description{
Interpolate Sa(p) at arbitrary period using log-log interpolation
}
\examples{
uhs <- data.table::data.table(
  Tn = c(0.2, 0.5, 1.0, 0.2, 0.5, 1.0),
  p  = c("0.16", "0.16", "0.16", "0.84", "0.84", "0.84"),
  Sa = c(0.8, 0.6, 0.3, 1.2, 0.9, 0.5)
)
interpolateSaTable(uhs, Tn = 0.3)
}
