% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Dn_models.R
\name{Dn_BM19}
\alias{Dn_BM19}
\title{Bray & Macedo (2019, corrected 2023) - shallow-crustal events}
\usage{
Dn_BM19(ky, Ts, Sa, PGA, PGV, Mw = 6.5, NFC = "D100")
}
\arguments{
\item{ky}{Yield acceleration (g).}

\item{Ts}{Fundamental period (s).}

\item{Sa}{Spectral acceleration at 1.3 * Ts (g).}

\item{PGA}{Peak ground acceleration (g).}

\item{PGV}{Peak ground velocity (cm/s).}

\item{Mw}{Moment magnitude (default 6.5).}

\item{NFC}{Near-fault component: "D100" (default; max-component, slope
within 45 deg of fault-normal) or "D50" (median-component, other
orientations). Used only when PGV > 115 cm/s.}
}
\value{
data.table(muLnD, sdLnD, ID = "BM19")
}
\description{
Multi-equation structure per BM23 (Soil Dynamics and Earthquake Engineering
168, 107835, DOI 10.1016/j.soildyn.2023.107835):
Eq (10): ordinary motions, PGV <= 115 cm/s
Eq (6):  D100 max-component, PGV > 115 cm/s
Eq (7):  D50  median-component, PGV > 115 cm/s
with a sub-regime split at PGV = 150 cm/s within Eqs (6) and (7).
}
\examples{
Dn_BM19(ky = 0.1, Ts = 0.3, Sa = 0.8, PGA = 0.5, PGV = 80, Mw = 7.0)
}
